.. -*- mode: rst -*-

|python_version|_ |pypi_version|_

.. |pypi_version| image:: http://img.shields.io/pypi/v/orsaytrace.svg?style=flat
.. _pypi_version: https://pypi.python.org/pypi/orsaytrace

.. |python_version| image:: https://img.shields.io/pypi/pyversions/orsaytrace.svg?style=flat
.. _python_version: https://pypi.python.org/pypi/orsaytrace


OrsayTrace
------------

Orsaytrace is an open source python library for flexible optical simulations in 3D dimensions. 

Orsaytrace makes it easy to add elements or transformations sequentially. Multiple shapes can be created using building blocks such as spheres, prisms, parabolas and spatial transformations like rotations or translations.

Data analysis are done by the means of plans, which save the photons that cross them during simulation running. A pletora of pre build functions are already implemented for photons subset, but users can build their own using all available photon objects.

Contributing 
------------

Contributing is encouraged for everyone. Please be in touch if you wish to help.
